@@ -48,39 +48,10 @@ class ChangeTicketStateOnVersionStatusChange(Hook):
             for ticket in forentity.reverse_done_in:
                 iwf = ticket.cw_adapt_to('IWorkflowable')
                 if iwf.state == 'done':
-                    msg = self._cw._('version published')
-                    try:
-                        iwf.fire_transition('ask validation',
-                                            comment=msg,
-                                            commentformat=u'text/plain')
-                    except ValidationError, ex:
-                        self.error('error while trying to change ticket state after version publishing: %s', ex)
-
-class AdjustPendingTicketState(Operation):
-    def precommit_event(self):
-        iwf = self.ticket.cw_adapt_to('IWorkflowable')
-        if (iwf.state == 'validation pending' and
-            (not self.ticket.done_in
-             or self.ticket.done_in[0].cw_adapt_to('IWorkflowable').state != 'published')):
-            msg = self.session._('moved away from published version')
-            iwf.change_state('open', comment=msg, commentformat=u'text/plain')
-
-
-class ChangeTicketStateOnDoneInChange(Hook):
-    """automatically add user who adds a comment to the nosy list"""
-    __regid__ = 'change_ticket_state_on_done'
-    events = ('after_delete_relation',)
-    __select__ = Hook.__select__ & hook.match_rtype('done_in',)
-
-    def __call__(self):
-        ticket = self._cw.entity_from_eid(self.eidfrom)
-        version = self._cw.entity_from_eid(self.eidto)
-        # only change tickets in the validation pending state, not done
-        # (since we want this behaviour to occurs for tickets moved
-        # from a published version to an unpublished one, usually because
-        # of non-validation
-        if ticket.cw_adapt_to('IWorkflowable').state == 'validation pending':
-            AdjustPendingTicketState(self._cw, ticket=ticket)
+                    msg = self._cw._('version %s published') % forentity.num
+                    iwf.fire_transition_if_possible('ask validation',
+                                                    comment=msg,
+                                                    commentformat=u'text/plain')
 
 
 class ResetLoadLeftOnTicketStatusChange(Hook):
