@@ -37,6 +37,7 @@ done       = twf.add_state(_('done'))
 vp         = twf.add_state(_('validation pending'))
 resolved   = twf.add_state(_('resolved'))
 deprecated = twf.add_state(_('deprecated'))
+notvalidated = twf.add_state(_('not validated'))
 
 twf.add_transition(_('start'), open, inprogress,
                    ('managers', 'staff'), xperm('developer'))
@@ -50,7 +51,9 @@ twf.add_transition(_('deprecate'), open, deprecated,
                    ('managers', 'staff'), xperm('client', 'developer'))
 twf.add_transition(_('resolve'), vp, resolved,
                    ('managers', 'staff'), xperm('client'))
-twf.add_transition(_('reopen'), (done, vp, rejected), open,
+twf.add_transition(_('reopen'), (done, rejected), open,
+                   ('managers', 'staff'), xperm('client'))
+twf.add_transition(_('refuse validation'), (vp,), notvalidated,
                    ('managers', 'staff'), xperm('client'))
 twf.add_transition(_('wait for feedback'), (open, inprogress), waiting,
                    ('managers', 'staff'), xperm('developer'))
