@@ -28,9 +28,9 @@ from yams.buildobjs import (EntityType, RelationDefinition,
 
 from cubicweb.schema import (RQLVocabularyConstraint, RRQLExpression,
                              ERQLExpression, make_workflowable)
-from cubes.tracker.schemaperms import sexpr, xexpr, xrexpr, xorexpr, xperm
+from cubes.tracker.schemaperms import sexpr, xexpr, xrexpr, xorexpr, xperm, restricted_oexpr
 
-from cubes.tracker.schema import Project, Ticket, Version
+from cubes.tracker.schema import Project, Ticket, Version, done_in
 from cubes.file.schema import File
 from cubes.card.schema import Card
 
@@ -38,12 +38,6 @@ Project.add_relation(String(maxsize=128,
                             description=_('url to project\'s home page. Leave this field '
                                           'empty if the project is fully hosted here.')),
                      name='homepage')
-Project.add_relation(String(maxsize=256,
-                            description=_('url to access to the project\'s version control system')),
-                     name='vcsurl')
-Project.add_relation(String(maxsize=256,
-                            description=_('url to access to the project\'s automatic test reports')),
-                     name='reporturl')
 Project.add_relation(String(maxsize=256,
                             description=_('url to access tarball for releases of the project')),
                      name='downloadurl')
@@ -56,6 +50,11 @@ Project.get_relations('uses').next().constraints = [
 
 make_workflowable(Project)
 
+done_in.__permissions__['delete'] = (
+    'managers',
+    RRQLExpression('U in_group G, G name "staff", NOT (O in_state ST, ST name "published")'),
+    restricted_oexpr('O in_state ST, ST name "planned"', 'client'),)
+
 class recommends(RelationDefinition):
     __permissions__ = {
         'read':   ('managers', 'users', 'guests'),
@@ -139,6 +138,16 @@ Ticket.__permissions__['update'] = ('managers', 'staff',
                                     ERQLExpression('X owned_by U, X in_state S, S name "open"'),
                                     )
 
+class follow_up(RelationDefinition):
+    """link a ticket to another, not validated, ticket"""
+    __permissions__ = {
+        'read':   ('managers', 'users', 'guests'),
+        'add':    ('managers', 'staff', RRQLExpression(xperm('client'))),
+        'delete': ('managers',),
+        }
+    subject = 'Ticket'
+    object = 'Ticket'
+    cardinality = '??'
 
 class attachment(RelationDefinition):
     __permissions__ = {
