@@ -13,11 +13,11 @@ class AutomaticWebTest(AutomaticWebTest):
         for version in cursor.execute('Version X').entities():
             version.cw_adapt_to('IWorkflowable').change_state('published')
 
-def setup_module(*args):
+def setUpModule(*args):
     #XXX DOESNT WORK vreg_instrumentize(AutomaticWebTest)
     pass
 
-def teardown_module(options, results):
+def tearDownModule(*args):
     #if not options.exitfirst or not (results.errors or results.failures):
     #    print_untested_objects(AutomaticWebTest)
     pass
