@@ -1,4 +1,5 @@
 """Forge unit tests"""
+from __future__ import with_statement
 
 from datetime import datetime, timedelta
 
@@ -7,7 +8,7 @@ from logilab.common.testlib import unittest_main, SkipTest
 from cubicweb.devtools import ApptestConfiguration
 from cubicweb.devtools.testlib import AutoPopulateTest
 
-from cubicweb import ValidationError
+from cubicweb import ValidationError, Unauthorized
 from cubicweb import NoSelectableObject
 from cubicweb.web.views import actions, workflow, idownloadable
 
@@ -22,6 +23,20 @@ ONEDAY = timedelta(1)
 class ProjectTC(TrackerBaseTC):
     """Project"""
 
+    def test_followup_wf(self):
+        req = self.request()
+        ticket = self.execute('INSERT Ticket X: X title "parent", X concerns P, X load 1 '
+                              'WHERE P is Project').get_entity(0, 0)
+        self.commit()
+        iworkflowable = ticket.cw_adapt_to('IWorkflowable')
+        for tr, state in [('done', 'done'), 
+                          ('ask validation', 'validation pending'),
+                          ('refuse validation', 'not validated')]:
+            iworkflowable.fire_transition(tr)
+            self.commit()
+            ticket.clear_all_caches()
+            self.assertEqual(iworkflowable.state, state)
+
     def test_tickets_rql(self):
         self.execute(self.cubicweb.active_tickets_rql()) # just check rql validity
         self.execute(*self.cubicweb.tickets_rql()) # just check rql validity
@@ -88,7 +103,7 @@ class ProjectTC(TrackerBaseTC):
                                (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid)
                                ])
         # logilab user
-        self.create_user('logilabien', ('staff', 'users'))
+        self.create_user(self.session, 'logilabien', ('staff', 'users'))
         self.login('logilabien')
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
@@ -132,7 +147,7 @@ class ProjectTC(TrackerBaseTC):
                               [])
         # std user, in dev project
         self.restore_connection()
-        self.create_user('toto')
+        self.create_user(self.session, 'toto')
         self.login('toto')
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
@@ -147,7 +162,8 @@ class ProjectTC(TrackerBaseTC):
                               [])
         # std user with perm, in dev project
         self.restore_connection()# use the admin connection to create and link a permission
-        self.grant_permission(self.cubicweb, 'users', 'developer', 'soumettre sur cubicweb')
+        self.grant_permission(self.session, self.cubicweb, 'users', 'developer',
+                              'soumettre sur cubicweb')
         # commit before opening a new connection
         self.commit()
         self.login('toto')
@@ -170,7 +186,8 @@ class ProjectTC(TrackerBaseTC):
                               [])
         # std user with client perm, in dev project
         self.restore_connection()# use the admin connection to create and link a permission
-        self.grant_permission(self.cubicweb, 'users', 'client', 'nouvelle version')
+        self.grant_permission(self.session, self.cubicweb, 'users', 'client',
+                              'nouvelle version')
         self.commit()
         # commit before opening a new connection
         self.login('toto')
@@ -406,8 +423,8 @@ class TicketTC(TrackerBaseTC):
         self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
                               [(u'resolve', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
                                 (self.t1.eid, wf.transition_by_name('resolve').eid)),
-                               (u'reopen', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, wf.transition_by_name('reopen').eid)),
+                               (u'refuse validation', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
+                                (self.t1.eid, wf.transition_by_name('refuse validation').eid)),
                                (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid),
                                (u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
         self.t1.cw_adapt_to('IWorkflowable').fire_transition('resolve')
@@ -463,17 +480,12 @@ class TicketTC(TrackerBaseTC):
         self.commit()
         self.t1.clear_all_caches()
         self.assertEqual(t1iwf.state, 'validation pending')
-        # # if the ticket is then moved to no version or to an unpublished version,
-        # # reopen it.
-        self.t1.set_relations(done_in=self.v)
-        self.commit()
-        self.t1.clear_all_caches()
-        self.assertEqual(t1iwf.state, 'open')
 
     def test_version_publishing_cant_change_ticket_state(self):
         self.execute('INSERT CWGroup X: X name "cubicwebdevelopers"')
-        self.grant_permission(self.cubicweb, 'cubicwebdevelopers', u'developer')
-        self.create_user('prj1client', groups=('users', 'cubicwebdevelopers'))
+        self.grant_permission(self.session, self.cubicweb, 'cubicwebdevelopers',
+                              u'developer')
+        self.create_user(self.session, 'prj1client', groups=('users', 'cubicwebdevelopers'))
         self.commit()
         self.t1.set_relations(done_in=self.v)
         # -  change ticket status
@@ -489,11 +501,24 @@ class TicketTC(TrackerBaseTC):
         self.login('prj1client')
         v2 =  self.execute('Any X WHERE X version_of P, P name "cubicweb", P is Project, X num "0.0.0"').get_entity(0, 0)
         t1 =  self.execute('Any X WHERE X in_state S, S name SN, X eid %s'% self.t1.eid).get_entity(0, 0)
+        # - can't change ticket's state
         t1iwf= t1.cw_adapt_to('IWorkflowable')
         self.assertRaises(ValidationError, t1iwf.fire_transition, 'ask validation')
+        self.rollback()
         v2.cw_adapt_to('IWorkflowable').fire_transition('publish')
+        self.commit()
         # - verify that ticket on which permissions were revoked remains in state
         self.assertEqual(t1iwf.state, 'done')
+        # only managers are enabled to move away ticket from a published version
+        self.assertRaises(Unauthorized, self.execute,
+                          'DELETE X done_in V WHERE X eid %(x)s', {'x': t1.eid})
+        self.rollback()
+        self.restore_connection()
+        self.create_user(self.session, 'staffuser', groups=('users', 'staff',))
+        with self.login('staffuser'):
+            self.assertRaises(Unauthorized, self.execute,
+                              'DELETE X done_in V WHERE X eid %(x)s', {'x': t1.eid})
+            self.rollback()
 
 
 class CommentTC(AutoPopulateTest):
@@ -516,13 +541,14 @@ class CommentTC(AutoPopulateTest):
             except AttributeError:
                 self.fail('%s class does not implement the project property' % etype)
 
+
 class FTITC(TrackerBaseTC):
     config = ApptestConfiguration('data', apphome=CommentTC.datadir,
                                   sourcefile='sources_fti')
     @classmethod
-    def _build_repo(cls, *args, **kwargs):
+    def _init_repo(cls, *args, **kwargs):
         try:
-            super(FTITC, cls)._build_repo(*args, **kwargs)
+            super(FTITC, cls)._init_repo(*args, **kwargs)
         except Exception, ex:
             # much probably on a wrong host
             raise SkipTest(ex)
