@@ -79,6 +79,9 @@ _pvs.tag_object_of(('*', 'documented_by', '*'), 'hidden')
 _pvs.tag_subject_of(('Ticket', 'attachment', '*'), 'sideboxes')
 _pvs.tag_object_of(('*', 'generate_bug', 'Ticket'), 'sideboxes')
 
+_pvs.tag_subject_of(('Ticket', 'follow_up', '*'), 'hidden')
+_pvs.tag_object_of(('*', 'follow_up', 'Ticket'), 'hidden')
+
 _pvs.tag_attribute(('ExtProject', 'name'), 'hidden')
 
 _pvs.tag_attribute(('License', 'name'), 'hidden')
