@@ -1,7 +1,7 @@
 """forge components boxes
 
 :organization: Logilab
-:copyright: 2006-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -9,10 +9,11 @@ __docformat__ = "restructuredtext en"
 from logilab.mtconverter import xml_escape
 
 from cubicweb.schema import display_name
-from cubicweb.selectors import is_instance, score_entity
+from cubicweb.selectors import is_instance, score_entity, has_related_entities
 from cubicweb.view import EntityAdapter
 from cubicweb.web import component
 from cubicweb.web.views import boxes
+from cubicweb.utils import transitive_closure_of
 
 class VersionIDownloadableAdapter(EntityAdapter):
     __regid__ = 'IDownloadable'
@@ -56,6 +57,34 @@ class ProjectDownloadBox(component.EntityCtxComponent):
             project.downloadurl, self._cw._('see them all')))
 
 
+class FollowupSideboxView(component.EntityCtxComponent):
+    __regid__ = 'forge.followup_history'
+    __select__ = (component.EntityCtxComponent.__select__ &
+                  is_instance('Ticket') &
+                  has_related_entities('follow_up', 'object') |
+                  has_related_entities('follow_up', 'subject'))
+
+    title = 'ticket traceability chain'
+    context = 'incontext'
+    wrapper = '<dt class="%s">%s - %s</dt>'
+
+    def render_body(self, w):
+        self._cw.add_css('cubes.forge.css')
+        ticket = self.entity
+        parent = transitive_closure_of(ticket, 'follow_up')
+        children = transitive_closure_of(ticket, 'reverse_follow_up')
+        w(u'<dl id="tabs">')
+        for elt in reversed(list(parent)[1:]):
+            w(self.wrapper % ('other',
+                              elt.view('incontext'),
+                              elt.cw_adapt_to('IWorkflowable').state))
+        w(self.wrapper % ('current', ticket.view('incontext'),
+                          ticket.cw_adapt_to('IWorkflowable').state))
+        for elt in list(children)[1:]:
+            w(self.wrapper % ('other',
+                              elt.view('incontext'),
+                              elt.cw_adapt_to('IWorkflowable').state))
+        w(u'</dl>')
 
 class ImageSideboxView(boxes.RsetBox): # XXX Project.screenshots / Ticket.attachment
     __select__ = boxes.RsetBox.__select__ & is_instance('File')
