@@ -23,10 +23,6 @@ class ForgeLinkedDataProjectItemView(doap_tracker.LinkedDataProjectItemView):
         self.w(u' <doap:Project rdf:about="%s">\n' % xml_escape(entity.absolute_url()))
         self.common_doap(entity)
         self.w(u'  <doap:homepage>%s</doap:homepage>\n' % xml_escape(entity.homepage or entity.absolute_url()))
-        if entity.vcsurl:
-            self.w(u'''<mercurial-repository>
-                          <doap:browse rdf:resource="%s" />
-                       </mercurial-repository>''' % xml_escape(entity.vcsurl))
         if entity.downloadurl:
             self.w(u'  <doap:download-page>%s</doap:download-page>\n' % xml_escape(entity.downloadurl))
         self.project_references(entity, 'uses')
@@ -63,12 +59,6 @@ class ForgeProjectDoapItemView(ForgeLinkedDataProjectItemView, doap_tracker.Proj
         # mailing list
         for ml in entity.reverse_mailinglist_of:
             ml.view('doapitem', w=self.w)
-        # repository
-        if entity.vcsurl:
-            self.w(u'<!--doap:repository tag does not exist -->')
-            self.w(u'  <doap:repository>\n')
-            self.w(u'    <doap:browse rdf:resource="%s" />\n' % xml_escape(entity.vcsurl))
-            self.w(u'  </doap:repository>\n')
         for lic in entity.reverse_license_of:
             self.w(u'  <doap:license rdf:resource="%s" />\n' % xml_escape(lic.absolute_url()))
         self.w(u'</doap:Project>\n')
