@@ -36,8 +36,7 @@ class ExtProjectPrimaryView(primary.PrimaryView):
                % (entity.dc_type().capitalize(), title))
 
 tracker.ProjectPrimaryView.tabs +=  [
-    _('documentation_tab'), _('screenshots_tab'),
-    _('codebrowser_tab')]
+    _('documentation_tab'), _('screenshots_tab')]
 
 
 _pvs = uicfg.primaryview_section
@@ -49,7 +48,7 @@ _pvs.tag_object_of(('*', 'mailinglist_of', 'Project'), 'attributes')
 _pvs.tag_subject_of(('*', 'documented_by', '*'), 'hidden')
 
 _pvdc = uicfg.primaryview_display_ctrl
-for attr in ('homepage', 'vcsurl', 'reporturl', 'downloadurl'):
+for attr in ('homepage', 'downloadurl'):
     _pvdc.tag_attribute(('Project', attr), {'vid': 'urlattr'})
 
 
@@ -81,28 +80,6 @@ class ProjectScreenshotsTab(ProjectScreenshotsView):
     __select__ = tabs.EntityRelationView.__select__ & is_instance('Project')
     title = None # should not appears in possible views
 
-class ProjectBrowseTab(EntityView):
-    __regid__ = 'codebrowser_tab'
-    __select__ = is_instance('Project') & score_entity(lambda x: x.vcsurl)
-    title = None # should not appears in possible views
-
-    def cell_call(self, row, col):
-        entity = self.cw_rset.get_entity(row, col)
-        # XXX browse sub-tab
-        # XXX may not be an hg repo
-        w = self.w
-        _ = self._cw._
-        w(u'<h4>%s</h4>' % _('Browse source'))
-        w(u'<p>%s</p>' % _('You can browse the source code by following <a href="%s">this link</a>.')
-          % xml_escape(entity.vcsurl))
-        w(u'<h4>%s</h4>' % _('Command-Line Access'))
-        w(u'<p>%s</p>' % _('Use this command to check out the latest project source code:'))
-        w(u'<br/><pre>')
-        w(u'# %s' % _('Non-members may check out a read-only working copy anonymously over HTTP.'))
-        w(u'<br/>')
-        w(u'hg clone %s' % xml_escape(entity.vcsurl))
-        w(u'</pre>')
-
 
 # secondary views ##############################################################
 
@@ -152,18 +129,6 @@ class ProjectOutOfContextView(tracker.ProjectOutOfContextView):
 
 # Project actions #############################################################
 
-class ProjectTestReportsAction(action.Action):
-    __regid__ = 'testreports'
-    __select__ = is_instance('Project') & score_entity(lambda x: x.reporturl)
-
-    title = _('test reports')
-    order = 220
-    def url(self):
-        entity = self.cw_rset.get_entity(0, 0)
-        rql = uilib.rql_for_eid(entity.eid)
-        return self._cw.build_url('embed', rql=rql, url=entity.reporturl,
-                              vtitle=self._cw._(self.title))
-
 class ProjectAddRelatedAction(action.LinkToEntityAction):
     __select__ = (action.LinkToEntityAction.__select__ & is_instance('Project')
                   & score_entity(lambda x: x.cw_adapt_to('IWorkflowable').state != 'moved'))
