@@ -7,10 +7,10 @@
 __docformat__ = "restructuredtext en"
 _ = unicode
 
-from cubicweb.selectors import one_line_rset, is_instance
-from cubicweb.web import component
-from cubicweb.web.views import tabs
-
+from logilab.mtconverter import xml_escape
+from cubicweb.web import component, box
+from cubicweb.web.views import tabs, primary
+from cubicweb.selectors import one_line_rset, is_instance, has_related_entities
 
 class TicketTestCardCtxComponent(component.RelatedObjectsCtxComponent):
     """display project's test cards"""
@@ -24,7 +24,6 @@ class TicketTestCardCtxComponent(component.RelatedObjectsCtxComponent):
     context = 'navcontentbottom'
     order = 30
 
-
 class TicketScreenshotsView(tabs.EntityRelationView):
     """display ticket's screenshots """
     __regid__ = 'ticketscreenshots'
