@@ -10,6 +10,7 @@ _ = unicode
 from cubicweb.selectors import is_instance
 from cubicweb.view import EntityView
 from cubicweb.web import uicfg, component
+from cubicweb.web.views import baseviews
 
 from cubes.tracker.views import version as tracker
 
@@ -19,6 +20,11 @@ for attr in ('progress_target', 'progress_done', 'progress_todo'):
 
 tracker.VersionPrimaryView.tabs.append(_('forge.version.burndown_tab'))
 
+# we don't want IDownloadable oneline view for version
+class VersionOneLineView(baseviews.OneLineView):
+    __select__ = is_instance('Version')
+
+
 class VersionBurndownChartTab(EntityView):
     __regid__ = 'forge.version.burndown_tab'
     __select__ = EntityView.__select__ & is_instance('Version')
@@ -47,22 +53,6 @@ class VersionBurndownChartTab(EntityView):
             self.wview('burndown_chart', tickets_rset, width=800, height=500)
 
 
-class VersionTestCardBarVComponent(component.RelatedObjectsVComponent):
-    """display version's test instances of test card"""
-    __regid__ = 'versiontests'
-    __select__ = component.RelatedObjectsVComponent.__select__ & is_instance('Version')
-
-    rtype = 'for_version'
-    target = 'subject'
-
-    title = _('Test case instances')
-    context = 'navcontentbottom'
-    vid = 'table'
-
-    def rql(self):
-        return 'Any X,S WHERE X for_version E, E eid %(x)s, X in_state S'
-
-
 class VersionProgressTableView(tracker.VersionProgressTableView):
     columns = (_('project'), _('milestone'), _('state'), _('planned_start'),
                _('planned_delivery'),
